import z from 'zod';
export declare const findByIdProfileResponseSchema: z.ZodObject<z.objectUtil.extendShape<{
    id: z.ZodString;
    shortId: z.ZodNumber;
    phoneNumber: z.ZodEffects<z.ZodString, string, string>;
    secondaryPhoneNumber: z.ZodEffects<z.ZodNullable<z.ZodString>, string | null, string | null>;
    fullName: z.ZodString;
    firstName: z.ZodNullable<z.ZodString>;
    gender: z.ZodNullable<z.ZodString>;
    birthDate: z.ZodNullable<z.ZodPipeline<z.ZodString, z.ZodDate>>;
    profilePictureUrl: z.ZodNullable<z.ZodString>;
    instagram: z.ZodNullable<z.ZodString>;
    mail: z.ZodNullable<z.ZodString>;
    dni: z.ZodNullable<z.ZodString>;
    alternativeNames: z.ZodArray<z.ZodString, "many">;
    birthLocationId: z.ZodNullable<z.ZodString>;
    residenceLocationId: z.ZodNullable<z.ZodString>;
    isInTrash: z.ZodBoolean;
    movedToTrashDate: z.ZodNullable<z.ZodDate>;
    created_at: z.ZodDate;
    updated_at: z.ZodDate;
}, {
    residenceLocation: z.ZodNullable<z.ZodObject<{
        id: z.ZodString;
        latitude: z.ZodNumber;
        longitude: z.ZodNumber;
        country: z.ZodString;
        state: z.ZodString;
        city: z.ZodString;
        created_at: z.ZodDate;
        updated_at: z.ZodDate;
    }, "strip", z.ZodTypeAny, {
        id: string;
        latitude: number;
        longitude: number;
        created_at: Date;
        updated_at: Date;
        state: string;
        country: string;
        city: string;
    }, {
        id: string;
        latitude: number;
        longitude: number;
        created_at: Date;
        updated_at: Date;
        state: string;
        country: string;
        city: string;
    }>>;
    birthLocation: z.ZodNullable<z.ZodObject<{
        id: z.ZodString;
        latitude: z.ZodNumber;
        longitude: z.ZodNumber;
        country: z.ZodString;
        state: z.ZodString;
        city: z.ZodString;
        created_at: z.ZodDate;
        updated_at: z.ZodDate;
    }, "strip", z.ZodTypeAny, {
        id: string;
        latitude: number;
        longitude: number;
        created_at: Date;
        updated_at: Date;
        state: string;
        country: string;
        city: string;
    }, {
        id: string;
        latitude: number;
        longitude: number;
        created_at: Date;
        updated_at: Date;
        state: string;
        country: string;
        city: string;
    }>>;
    tags: z.ZodArray<z.ZodObject<z.objectUtil.extendShape<{
        id: z.ZodString;
        name: z.ZodString;
        groupId: z.ZodString;
        type: z.ZodNativeEnum<{
            PROFILE: "PROFILE";
            EVENT: "EVENT";
            PARTICIPANT: "PARTICIPANT";
            NOT_IN_SYSTEM: "NOT_IN_SYSTEM";
        }>;
        created_at: z.ZodDate;
        updated_at: z.ZodDate;
    }, {
        group: z.ZodObject<Pick<{
            id: z.ZodString;
            name: z.ZodString;
            color: z.ZodString;
            isExclusive: z.ZodBoolean;
            created_at: z.ZodDate;
            updated_at: z.ZodDate;
        }, "id" | "color" | "isExclusive">, "strip", z.ZodTypeAny, {
            id: string;
            color: string;
            isExclusive: boolean;
        }, {
            id: string;
            color: string;
            isExclusive: boolean;
        }>;
    }>, "strip", z.ZodTypeAny, {
        id: string;
        name: string;
        type: "PROFILE" | "EVENT" | "PARTICIPANT" | "NOT_IN_SYSTEM";
        created_at: Date;
        updated_at: Date;
        groupId: string;
        group: {
            id: string;
            color: string;
            isExclusive: boolean;
        };
    }, {
        id: string;
        name: string;
        type: "PROFILE" | "EVENT" | "PARTICIPANT" | "NOT_IN_SYSTEM";
        created_at: Date;
        updated_at: Date;
        groupId: string;
        group: {
            id: string;
            color: string;
            isExclusive: boolean;
        };
    }>, "many">;
}>, "strip", z.ZodTypeAny, {
    id: string;
    phoneNumber: string;
    secondaryPhoneNumber: string | null;
    fullName: string;
    profilePictureUrl: string | null;
    mail: string | null;
    created_at: Date;
    updated_at: Date;
    tags: {
        id: string;
        name: string;
        type: "PROFILE" | "EVENT" | "PARTICIPANT" | "NOT_IN_SYSTEM";
        created_at: Date;
        updated_at: Date;
        groupId: string;
        group: {
            id: string;
            color: string;
            isExclusive: boolean;
        };
    }[];
    shortId: number;
    firstName: string | null;
    gender: string | null;
    birthDate: Date | null;
    instagram: string | null;
    dni: string | null;
    alternativeNames: string[];
    birthLocationId: string | null;
    residenceLocationId: string | null;
    isInTrash: boolean;
    movedToTrashDate: Date | null;
    residenceLocation: {
        id: string;
        latitude: number;
        longitude: number;
        created_at: Date;
        updated_at: Date;
        state: string;
        country: string;
        city: string;
    } | null;
    birthLocation: {
        id: string;
        latitude: number;
        longitude: number;
        created_at: Date;
        updated_at: Date;
        state: string;
        country: string;
        city: string;
    } | null;
}, {
    id: string;
    phoneNumber: string;
    secondaryPhoneNumber: string | null;
    fullName: string;
    profilePictureUrl: string | null;
    mail: string | null;
    created_at: Date;
    updated_at: Date;
    tags: {
        id: string;
        name: string;
        type: "PROFILE" | "EVENT" | "PARTICIPANT" | "NOT_IN_SYSTEM";
        created_at: Date;
        updated_at: Date;
        groupId: string;
        group: {
            id: string;
            color: string;
            isExclusive: boolean;
        };
    }[];
    shortId: number;
    firstName: string | null;
    gender: string | null;
    birthDate: string | null;
    instagram: string | null;
    dni: string | null;
    alternativeNames: string[];
    birthLocationId: string | null;
    residenceLocationId: string | null;
    isInTrash: boolean;
    movedToTrashDate: Date | null;
    residenceLocation: {
        id: string;
        latitude: number;
        longitude: number;
        created_at: Date;
        updated_at: Date;
        state: string;
        country: string;
        city: string;
    } | null;
    birthLocation: {
        id: string;
        latitude: number;
        longitude: number;
        created_at: Date;
        updated_at: Date;
        state: string;
        country: string;
        city: string;
    } | null;
}>;
declare const FindByIdProfileResponseDto_base: import("@anatine/zod-nestjs").ZodDtoStatic<z.ZodObject<{
    id: z.ZodString;
    shortId: z.ZodNumber;
    phoneNumber: z.ZodEffects<z.ZodString, string, string>;
    secondaryPhoneNumber: z.ZodEffects<z.ZodNullable<z.ZodString>, string | null, string | null>;
    fullName: z.ZodString;
    firstName: z.ZodNullable<z.ZodString>;
    gender: z.ZodNullable<z.ZodString>;
    birthDate: z.ZodNullable<z.ZodPipeline<z.ZodString, z.ZodDate>>;
    profilePictureUrl: z.ZodNullable<z.ZodString>;
    instagram: z.ZodNullable<z.ZodString>;
    mail: z.ZodNullable<z.ZodString>;
    dni: z.ZodNullable<z.ZodString>;
    alternativeNames: z.ZodArray<z.ZodString, "many">;
    birthLocationId: z.ZodNullable<z.ZodString>;
    residenceLocationId: z.ZodNullable<z.ZodString>;
    isInTrash: z.ZodBoolean;
    movedToTrashDate: z.ZodNullable<z.ZodString>;
    created_at: z.ZodString;
    updated_at: z.ZodString;
    residenceLocation: z.ZodNullable<z.ZodObject<{
        id: z.ZodString;
        latitude: z.ZodNumber;
        longitude: z.ZodNumber;
        country: z.ZodString;
        state: z.ZodString;
        city: z.ZodString;
        created_at: z.ZodString;
        updated_at: z.ZodString;
    }, z.UnknownKeysParam, z.ZodTypeAny, {
        id: string;
        latitude: number;
        longitude: number;
        created_at: string;
        updated_at: string;
        state: string;
        country: string;
        city: string;
    }, {
        id: string;
        latitude: number;
        longitude: number;
        created_at: string;
        updated_at: string;
        state: string;
        country: string;
        city: string;
    }>>;
    birthLocation: z.ZodNullable<z.ZodObject<{
        id: z.ZodString;
        latitude: z.ZodNumber;
        longitude: z.ZodNumber;
        country: z.ZodString;
        state: z.ZodString;
        city: z.ZodString;
        created_at: z.ZodString;
        updated_at: z.ZodString;
    }, z.UnknownKeysParam, z.ZodTypeAny, {
        id: string;
        latitude: number;
        longitude: number;
        created_at: string;
        updated_at: string;
        state: string;
        country: string;
        city: string;
    }, {
        id: string;
        latitude: number;
        longitude: number;
        created_at: string;
        updated_at: string;
        state: string;
        country: string;
        city: string;
    }>>;
    tags: z.ZodArray<z.ZodObject<{
        id: z.ZodString;
        name: z.ZodString;
        groupId: z.ZodString;
        type: z.ZodNativeEnum<{
            PROFILE: "PROFILE";
            EVENT: "EVENT";
            PARTICIPANT: "PARTICIPANT";
            NOT_IN_SYSTEM: "NOT_IN_SYSTEM";
        }>;
        created_at: z.ZodString;
        updated_at: z.ZodString;
        group: z.ZodObject<{
            id: z.ZodString;
            color: z.ZodString;
            isExclusive: z.ZodBoolean;
        }, z.UnknownKeysParam, z.ZodTypeAny, {
            id: string;
            color: string;
            isExclusive: boolean;
        }, {
            id: string;
            color: string;
            isExclusive: boolean;
        }>;
    }, z.UnknownKeysParam, z.ZodTypeAny, {
        id: string;
        name: string;
        type: "PROFILE" | "EVENT" | "PARTICIPANT" | "NOT_IN_SYSTEM";
        created_at: string;
        updated_at: string;
        groupId: string;
        group: {
            id: string;
            color: string;
            isExclusive: boolean;
        };
    }, {
        id: string;
        name: string;
        type: "PROFILE" | "EVENT" | "PARTICIPANT" | "NOT_IN_SYSTEM";
        created_at: string;
        updated_at: string;
        groupId: string;
        group: {
            id: string;
            color: string;
            isExclusive: boolean;
        };
    }>, "many">;
}, z.UnknownKeysParam, z.ZodTypeAny, {
    id: string;
    phoneNumber: string;
    secondaryPhoneNumber: string | null;
    fullName: string;
    profilePictureUrl: string | null;
    mail: string | null;
    created_at: string;
    updated_at: string;
    tags: {
        id: string;
        name: string;
        type: "PROFILE" | "EVENT" | "PARTICIPANT" | "NOT_IN_SYSTEM";
        created_at: string;
        updated_at: string;
        groupId: string;
        group: {
            id: string;
            color: string;
            isExclusive: boolean;
        };
    }[];
    shortId: number;
    firstName: string | null;
    gender: string | null;
    birthDate: Date | null;
    instagram: string | null;
    dni: string | null;
    alternativeNames: string[];
    birthLocationId: string | null;
    residenceLocationId: string | null;
    isInTrash: boolean;
    movedToTrashDate: string | null;
    residenceLocation: {
        id: string;
        latitude: number;
        longitude: number;
        created_at: string;
        updated_at: string;
        state: string;
        country: string;
        city: string;
    } | null;
    birthLocation: {
        id: string;
        latitude: number;
        longitude: number;
        created_at: string;
        updated_at: string;
        state: string;
        country: string;
        city: string;
    } | null;
}, {
    id: string;
    phoneNumber: string;
    secondaryPhoneNumber: string | null;
    fullName: string;
    profilePictureUrl: string | null;
    mail: string | null;
    created_at: string;
    updated_at: string;
    tags: {
        id: string;
        name: string;
        type: "PROFILE" | "EVENT" | "PARTICIPANT" | "NOT_IN_SYSTEM";
        created_at: string;
        updated_at: string;
        groupId: string;
        group: {
            id: string;
            color: string;
            isExclusive: boolean;
        };
    }[];
    shortId: number;
    firstName: string | null;
    gender: string | null;
    birthDate: string | null;
    instagram: string | null;
    dni: string | null;
    alternativeNames: string[];
    birthLocationId: string | null;
    residenceLocationId: string | null;
    isInTrash: boolean;
    movedToTrashDate: string | null;
    residenceLocation: {
        id: string;
        latitude: number;
        longitude: number;
        created_at: string;
        updated_at: string;
        state: string;
        country: string;
        city: string;
    } | null;
    birthLocation: {
        id: string;
        latitude: number;
        longitude: number;
        created_at: string;
        updated_at: string;
        state: string;
        country: string;
        city: string;
    } | null;
}>>;
export declare class FindByIdProfileResponseDto extends FindByIdProfileResponseDto_base {
}
export {};
