import z from 'zod';
export declare const findWithActiveChatResponseSchema: z.ZodObject<{
    profiles: z.ZodArray<z.ZodObject<z.objectUtil.extendShape<{
        id: z.ZodString;
        shortId: z.ZodNumber;
        phoneNumber: z.ZodEffects<z.ZodString, string, string>;
        secondaryPhoneNumber: z.ZodEffects<z.ZodNullable<z.ZodString>, string | null, string | null>;
        fullName: z.ZodString;
        firstName: z.ZodNullable<z.ZodString>;
        gender: z.ZodNullable<z.ZodString>;
        birthDate: z.ZodNullable<z.ZodPipeline<z.ZodString, z.ZodDate>>;
        profilePictureUrl: z.ZodNullable<z.ZodString>;
        instagram: z.ZodNullable<z.ZodString>;
        mail: z.ZodNullable<z.ZodString>;
        dni: z.ZodNullable<z.ZodString>;
        alternativeNames: z.ZodArray<z.ZodString, "many">;
        birthLocationId: z.ZodNullable<z.ZodString>;
        residenceLocationId: z.ZodNullable<z.ZodString>;
        isInTrash: z.ZodBoolean;
        movedToTrashDate: z.ZodNullable<z.ZodDate>;
        created_at: z.ZodDate;
        updated_at: z.ZodDate;
    }, {
        tags: z.ZodArray<z.ZodObject<{
            id: z.ZodString;
            name: z.ZodString;
            groupId: z.ZodString;
            type: z.ZodNativeEnum<{
                PROFILE: "PROFILE";
                EVENT: "EVENT";
                PARTICIPANT: "PARTICIPANT";
                NOT_IN_SYSTEM: "NOT_IN_SYSTEM";
            }>;
            created_at: z.ZodDate;
            updated_at: z.ZodDate;
        }, "strip", z.ZodTypeAny, {
            id: string;
            name: string;
            type: "PROFILE" | "EVENT" | "PARTICIPANT" | "NOT_IN_SYSTEM";
            created_at: Date;
            updated_at: Date;
            groupId: string;
        }, {
            id: string;
            name: string;
            type: "PROFILE" | "EVENT" | "PARTICIPANT" | "NOT_IN_SYSTEM";
            created_at: Date;
            updated_at: Date;
            groupId: string;
        }>, "many">;
        inChat: z.ZodBoolean;
        messages: z.ZodArray<z.ZodObject<Pick<{
            id: z.ZodString;
            wamId: z.ZodString;
            message: z.ZodDiscriminatedUnion<"type", [z.ZodObject<z.objectUtil.extendShape<z.objectUtil.extendShape<{
                id: z.ZodString;
                from: z.ZodOptional<z.ZodString>;
                to: z.ZodOptional<z.ZodString>;
                timestamp: z.ZodNumber;
            }, {
                text: z.ZodObject<{
                    body: z.ZodString;
                }, "strip", z.ZodTypeAny, {
                    body: string;
                }, {
                    body: string;
                }>;
            }>, {
                type: z.ZodLiteral<"text">;
            }>, "strip", z.ZodTypeAny, {
                id: string;
                type: "text";
                timestamp: number;
                text: {
                    body: string;
                };
                from?: string | undefined;
                to?: string | undefined;
            }, {
                id: string;
                type: "text";
                timestamp: number;
                text: {
                    body: string;
                };
                from?: string | undefined;
                to?: string | undefined;
            }>, z.ZodObject<z.objectUtil.extendShape<z.objectUtil.extendShape<{
                id: z.ZodString;
                from: z.ZodOptional<z.ZodString>;
                to: z.ZodOptional<z.ZodString>;
                timestamp: z.ZodNumber;
            }, {
                templateName: z.ZodString;
            }>, {
                type: z.ZodLiteral<"template">;
            }>, "strip", z.ZodTypeAny, {
                id: string;
                type: "template";
                timestamp: number;
                templateName: string;
                from?: string | undefined;
                to?: string | undefined;
            }, {
                id: string;
                type: "template";
                timestamp: number;
                templateName: string;
                from?: string | undefined;
                to?: string | undefined;
            }>]>;
            state: z.ZodNativeEnum<{
                SENT: "SENT";
                RECEIVED: "RECEIVED";
                SEEN: "SEEN";
            }>;
            created_at: z.ZodDate;
            updated_at: z.ZodDate;
        }, "message" | "created_at" | "state">, "strip", z.ZodTypeAny, {
            message: {
                id: string;
                type: "text";
                timestamp: number;
                text: {
                    body: string;
                };
                from?: string | undefined;
                to?: string | undefined;
            } | {
                id: string;
                type: "template";
                timestamp: number;
                templateName: string;
                from?: string | undefined;
                to?: string | undefined;
            };
            created_at: Date;
            state: "SENT" | "RECEIVED" | "SEEN";
        }, {
            message: {
                id: string;
                type: "text";
                timestamp: number;
                text: {
                    body: string;
                };
                from?: string | undefined;
                to?: string | undefined;
            } | {
                id: string;
                type: "template";
                timestamp: number;
                templateName: string;
                from?: string | undefined;
                to?: string | undefined;
            };
            created_at: Date;
            state: "SENT" | "RECEIVED" | "SEEN";
        }>, "many">;
    }>, "strip", z.ZodTypeAny, {
        id: string;
        phoneNumber: string;
        secondaryPhoneNumber: string | null;
        fullName: string;
        profilePictureUrl: string | null;
        mail: string | null;
        created_at: Date;
        updated_at: Date;
        tags: {
            id: string;
            name: string;
            type: "PROFILE" | "EVENT" | "PARTICIPANT" | "NOT_IN_SYSTEM";
            created_at: Date;
            updated_at: Date;
            groupId: string;
        }[];
        shortId: number;
        firstName: string | null;
        gender: string | null;
        birthDate: Date | null;
        instagram: string | null;
        dni: string | null;
        alternativeNames: string[];
        birthLocationId: string | null;
        residenceLocationId: string | null;
        isInTrash: boolean;
        movedToTrashDate: Date | null;
        inChat: boolean;
        messages: {
            message: {
                id: string;
                type: "text";
                timestamp: number;
                text: {
                    body: string;
                };
                from?: string | undefined;
                to?: string | undefined;
            } | {
                id: string;
                type: "template";
                timestamp: number;
                templateName: string;
                from?: string | undefined;
                to?: string | undefined;
            };
            created_at: Date;
            state: "SENT" | "RECEIVED" | "SEEN";
        }[];
    }, {
        id: string;
        phoneNumber: string;
        secondaryPhoneNumber: string | null;
        fullName: string;
        profilePictureUrl: string | null;
        mail: string | null;
        created_at: Date;
        updated_at: Date;
        tags: {
            id: string;
            name: string;
            type: "PROFILE" | "EVENT" | "PARTICIPANT" | "NOT_IN_SYSTEM";
            created_at: Date;
            updated_at: Date;
            groupId: string;
        }[];
        shortId: number;
        firstName: string | null;
        gender: string | null;
        birthDate: string | null;
        instagram: string | null;
        dni: string | null;
        alternativeNames: string[];
        birthLocationId: string | null;
        residenceLocationId: string | null;
        isInTrash: boolean;
        movedToTrashDate: Date | null;
        inChat: boolean;
        messages: {
            message: {
                id: string;
                type: "text";
                timestamp: number;
                text: {
                    body: string;
                };
                from?: string | undefined;
                to?: string | undefined;
            } | {
                id: string;
                type: "template";
                timestamp: number;
                templateName: string;
                from?: string | undefined;
                to?: string | undefined;
            };
            created_at: Date;
            state: "SENT" | "RECEIVED" | "SEEN";
        }[];
    }>, "many">;
}, "strip", z.ZodTypeAny, {
    profiles: {
        id: string;
        phoneNumber: string;
        secondaryPhoneNumber: string | null;
        fullName: string;
        profilePictureUrl: string | null;
        mail: string | null;
        created_at: Date;
        updated_at: Date;
        tags: {
            id: string;
            name: string;
            type: "PROFILE" | "EVENT" | "PARTICIPANT" | "NOT_IN_SYSTEM";
            created_at: Date;
            updated_at: Date;
            groupId: string;
        }[];
        shortId: number;
        firstName: string | null;
        gender: string | null;
        birthDate: Date | null;
        instagram: string | null;
        dni: string | null;
        alternativeNames: string[];
        birthLocationId: string | null;
        residenceLocationId: string | null;
        isInTrash: boolean;
        movedToTrashDate: Date | null;
        inChat: boolean;
        messages: {
            message: {
                id: string;
                type: "text";
                timestamp: number;
                text: {
                    body: string;
                };
                from?: string | undefined;
                to?: string | undefined;
            } | {
                id: string;
                type: "template";
                timestamp: number;
                templateName: string;
                from?: string | undefined;
                to?: string | undefined;
            };
            created_at: Date;
            state: "SENT" | "RECEIVED" | "SEEN";
        }[];
    }[];
}, {
    profiles: {
        id: string;
        phoneNumber: string;
        secondaryPhoneNumber: string | null;
        fullName: string;
        profilePictureUrl: string | null;
        mail: string | null;
        created_at: Date;
        updated_at: Date;
        tags: {
            id: string;
            name: string;
            type: "PROFILE" | "EVENT" | "PARTICIPANT" | "NOT_IN_SYSTEM";
            created_at: Date;
            updated_at: Date;
            groupId: string;
        }[];
        shortId: number;
        firstName: string | null;
        gender: string | null;
        birthDate: string | null;
        instagram: string | null;
        dni: string | null;
        alternativeNames: string[];
        birthLocationId: string | null;
        residenceLocationId: string | null;
        isInTrash: boolean;
        movedToTrashDate: Date | null;
        inChat: boolean;
        messages: {
            message: {
                id: string;
                type: "text";
                timestamp: number;
                text: {
                    body: string;
                };
                from?: string | undefined;
                to?: string | undefined;
            } | {
                id: string;
                type: "template";
                timestamp: number;
                templateName: string;
                from?: string | undefined;
                to?: string | undefined;
            };
            created_at: Date;
            state: "SENT" | "RECEIVED" | "SEEN";
        }[];
    }[];
}>;
declare const FindWithActiveChatResponseDto_base: import("@anatine/zod-nestjs").ZodDtoStatic<z.ZodObject<{
    profiles: z.ZodArray<z.ZodObject<{
        id: z.ZodString;
        shortId: z.ZodNumber;
        phoneNumber: z.ZodEffects<z.ZodString, string, string>;
        secondaryPhoneNumber: z.ZodEffects<z.ZodNullable<z.ZodString>, string | null, string | null>;
        fullName: z.ZodString;
        firstName: z.ZodNullable<z.ZodString>;
        gender: z.ZodNullable<z.ZodString>;
        birthDate: z.ZodNullable<z.ZodPipeline<z.ZodString, z.ZodDate>>;
        profilePictureUrl: z.ZodNullable<z.ZodString>;
        instagram: z.ZodNullable<z.ZodString>;
        mail: z.ZodNullable<z.ZodString>;
        dni: z.ZodNullable<z.ZodString>;
        alternativeNames: z.ZodArray<z.ZodString, "many">;
        birthLocationId: z.ZodNullable<z.ZodString>;
        residenceLocationId: z.ZodNullable<z.ZodString>;
        isInTrash: z.ZodBoolean;
        movedToTrashDate: z.ZodNullable<z.ZodString>;
        created_at: z.ZodString;
        updated_at: z.ZodString;
        tags: z.ZodArray<z.ZodObject<{
            id: z.ZodString;
            name: z.ZodString;
            groupId: z.ZodString;
            type: z.ZodNativeEnum<{
                PROFILE: "PROFILE";
                EVENT: "EVENT";
                PARTICIPANT: "PARTICIPANT";
                NOT_IN_SYSTEM: "NOT_IN_SYSTEM";
            }>;
            created_at: z.ZodString;
            updated_at: z.ZodString;
        }, z.UnknownKeysParam, z.ZodTypeAny, {
            id: string;
            name: string;
            type: "PROFILE" | "EVENT" | "PARTICIPANT" | "NOT_IN_SYSTEM";
            created_at: string;
            updated_at: string;
            groupId: string;
        }, {
            id: string;
            name: string;
            type: "PROFILE" | "EVENT" | "PARTICIPANT" | "NOT_IN_SYSTEM";
            created_at: string;
            updated_at: string;
            groupId: string;
        }>, "many">;
        inChat: z.ZodBoolean;
        messages: z.ZodArray<z.ZodObject<{
            message: z.ZodDiscriminatedUnion<"type", [z.ZodObject<z.objectUtil.extendShape<z.objectUtil.extendShape<{
                id: z.ZodString;
                from: z.ZodOptional<z.ZodString>;
                to: z.ZodOptional<z.ZodString>;
                timestamp: z.ZodNumber;
            }, {
                text: z.ZodObject<{
                    body: z.ZodString;
                }, "strip", z.ZodTypeAny, {
                    body: string;
                }, {
                    body: string;
                }>;
            }>, {
                type: z.ZodLiteral<"text">;
            }>, "strip", z.ZodTypeAny, {
                id: string;
                type: "text";
                timestamp: number;
                text: {
                    body: string;
                };
                from?: string | undefined;
                to?: string | undefined;
            }, {
                id: string;
                type: "text";
                timestamp: number;
                text: {
                    body: string;
                };
                from?: string | undefined;
                to?: string | undefined;
            }>, z.ZodObject<z.objectUtil.extendShape<z.objectUtil.extendShape<{
                id: z.ZodString;
                from: z.ZodOptional<z.ZodString>;
                to: z.ZodOptional<z.ZodString>;
                timestamp: z.ZodNumber;
            }, {
                templateName: z.ZodString;
            }>, {
                type: z.ZodLiteral<"template">;
            }>, "strip", z.ZodTypeAny, {
                id: string;
                type: "template";
                timestamp: number;
                templateName: string;
                from?: string | undefined;
                to?: string | undefined;
            }, {
                id: string;
                type: "template";
                timestamp: number;
                templateName: string;
                from?: string | undefined;
                to?: string | undefined;
            }>]>;
            created_at: z.ZodString;
            state: z.ZodNativeEnum<{
                SENT: "SENT";
                RECEIVED: "RECEIVED";
                SEEN: "SEEN";
            }>;
        }, z.UnknownKeysParam, z.ZodTypeAny, {
            message: {
                id: string;
                type: "text";
                timestamp: number;
                text: {
                    body: string;
                };
                from?: string | undefined;
                to?: string | undefined;
            } | {
                id: string;
                type: "template";
                timestamp: number;
                templateName: string;
                from?: string | undefined;
                to?: string | undefined;
            };
            created_at: string;
            state: "SENT" | "RECEIVED" | "SEEN";
        }, {
            message: {
                id: string;
                type: "text";
                timestamp: number;
                text: {
                    body: string;
                };
                from?: string | undefined;
                to?: string | undefined;
            } | {
                id: string;
                type: "template";
                timestamp: number;
                templateName: string;
                from?: string | undefined;
                to?: string | undefined;
            };
            created_at: string;
            state: "SENT" | "RECEIVED" | "SEEN";
        }>, "many">;
    }, z.UnknownKeysParam, z.ZodTypeAny, {
        id: string;
        phoneNumber: string;
        secondaryPhoneNumber: string | null;
        fullName: string;
        profilePictureUrl: string | null;
        mail: string | null;
        created_at: string;
        updated_at: string;
        tags: {
            id: string;
            name: string;
            type: "PROFILE" | "EVENT" | "PARTICIPANT" | "NOT_IN_SYSTEM";
            created_at: string;
            updated_at: string;
            groupId: string;
        }[];
        shortId: number;
        firstName: string | null;
        gender: string | null;
        birthDate: Date | null;
        instagram: string | null;
        dni: string | null;
        alternativeNames: string[];
        birthLocationId: string | null;
        residenceLocationId: string | null;
        isInTrash: boolean;
        movedToTrashDate: string | null;
        inChat: boolean;
        messages: {
            message: {
                id: string;
                type: "text";
                timestamp: number;
                text: {
                    body: string;
                };
                from?: string | undefined;
                to?: string | undefined;
            } | {
                id: string;
                type: "template";
                timestamp: number;
                templateName: string;
                from?: string | undefined;
                to?: string | undefined;
            };
            created_at: string;
            state: "SENT" | "RECEIVED" | "SEEN";
        }[];
    }, {
        id: string;
        phoneNumber: string;
        secondaryPhoneNumber: string | null;
        fullName: string;
        profilePictureUrl: string | null;
        mail: string | null;
        created_at: string;
        updated_at: string;
        tags: {
            id: string;
            name: string;
            type: "PROFILE" | "EVENT" | "PARTICIPANT" | "NOT_IN_SYSTEM";
            created_at: string;
            updated_at: string;
            groupId: string;
        }[];
        shortId: number;
        firstName: string | null;
        gender: string | null;
        birthDate: string | null;
        instagram: string | null;
        dni: string | null;
        alternativeNames: string[];
        birthLocationId: string | null;
        residenceLocationId: string | null;
        isInTrash: boolean;
        movedToTrashDate: string | null;
        inChat: boolean;
        messages: {
            message: {
                id: string;
                type: "text";
                timestamp: number;
                text: {
                    body: string;
                };
                from?: string | undefined;
                to?: string | undefined;
            } | {
                id: string;
                type: "template";
                timestamp: number;
                templateName: string;
                from?: string | undefined;
                to?: string | undefined;
            };
            created_at: string;
            state: "SENT" | "RECEIVED" | "SEEN";
        }[];
    }>, "many">;
}, z.UnknownKeysParam, z.ZodTypeAny, {
    profiles: {
        id: string;
        phoneNumber: string;
        secondaryPhoneNumber: string | null;
        fullName: string;
        profilePictureUrl: string | null;
        mail: string | null;
        created_at: string;
        updated_at: string;
        tags: {
            id: string;
            name: string;
            type: "PROFILE" | "EVENT" | "PARTICIPANT" | "NOT_IN_SYSTEM";
            created_at: string;
            updated_at: string;
            groupId: string;
        }[];
        shortId: number;
        firstName: string | null;
        gender: string | null;
        birthDate: Date | null;
        instagram: string | null;
        dni: string | null;
        alternativeNames: string[];
        birthLocationId: string | null;
        residenceLocationId: string | null;
        isInTrash: boolean;
        movedToTrashDate: string | null;
        inChat: boolean;
        messages: {
            message: {
                id: string;
                type: "text";
                timestamp: number;
                text: {
                    body: string;
                };
                from?: string | undefined;
                to?: string | undefined;
            } | {
                id: string;
                type: "template";
                timestamp: number;
                templateName: string;
                from?: string | undefined;
                to?: string | undefined;
            };
            created_at: string;
            state: "SENT" | "RECEIVED" | "SEEN";
        }[];
    }[];
}, {
    profiles: {
        id: string;
        phoneNumber: string;
        secondaryPhoneNumber: string | null;
        fullName: string;
        profilePictureUrl: string | null;
        mail: string | null;
        created_at: string;
        updated_at: string;
        tags: {
            id: string;
            name: string;
            type: "PROFILE" | "EVENT" | "PARTICIPANT" | "NOT_IN_SYSTEM";
            created_at: string;
            updated_at: string;
            groupId: string;
        }[];
        shortId: number;
        firstName: string | null;
        gender: string | null;
        birthDate: string | null;
        instagram: string | null;
        dni: string | null;
        alternativeNames: string[];
        birthLocationId: string | null;
        residenceLocationId: string | null;
        isInTrash: boolean;
        movedToTrashDate: string | null;
        inChat: boolean;
        messages: {
            message: {
                id: string;
                type: "text";
                timestamp: number;
                text: {
                    body: string;
                };
                from?: string | undefined;
                to?: string | undefined;
            } | {
                id: string;
                type: "template";
                timestamp: number;
                templateName: string;
                from?: string | undefined;
                to?: string | undefined;
            };
            created_at: string;
            state: "SENT" | "RECEIVED" | "SEEN";
        }[];
    }[];
}>>;
export declare class FindWithActiveChatResponseDto extends FindWithActiveChatResponseDto_base {
}
export {};
